@@ -6,11 +6,11 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KCMKONTACT_H
-#define KCMKONTACT_H
+#pragma once
 
 #include <KCModule>
-#include <KService>
+#include <KPluginMetaData>
+
 class QComboBox;
 class QCheckBox;
 namespace Kontact
@@ -20,7 +20,7 @@ class KcmKontact : public KCModule
     Q_OBJECT
 
 public:
-    explicit KcmKontact(QWidget *parent = nullptr);
+    explicit KcmKontact(QWidget *parent = nullptr, const QVariantList &args = {});
 
     void load() override;
     void save() override;
@@ -28,10 +28,8 @@ public:
     const KAboutData *aboutData() const override;
 
 private:
-    KService::List mPluginList;
-    QComboBox *mPluginCombo = nullptr;
-    QCheckBox *mShowSideBarCheckbox = nullptr;
+    QVector<KPluginMetaData> mPluginList;
+    QComboBox *const mPluginCombo;
 };
 }
 
-#endif
