@@ -51,6 +51,7 @@ using namespace Kontact;
 #include <KToolBar>
 #include <KWindowConfig>
 #include <KXMLGUIFactory>
+#include <QAction>
 #include <QApplication>
 #include <QDBusConnection>
 #include <QHBoxLayout>
@@ -62,6 +63,7 @@ using namespace Kontact;
 #include <QStatusBar>
 #include <QVBoxLayout>
 #include <QWebEngineUrlScheme>
+
 #include <ksettings/Dispatcher>
 
 #include <GrantleeTheme/GrantleeTheme>
@@ -153,7 +155,6 @@ void MainWindow::initObject()
     if (mSidePane) {
         mSidePane->updatePlugins();
     }
-    KSettings::Dispatcher::registerComponent(QStringLiteral("kontact"), this, "updateConfig");
 
     loadSettings();
 
@@ -218,7 +219,7 @@ bool MainWindow::pluginWeightLessThan(const KontactInterface::Plugin *left, cons
 void MainWindow::activateInitialPluginModule()
 {
     if (!mInitialActiveModule.isEmpty() && !mPlugins.isEmpty()) {
-        for (KontactInterface::Plugin *plugin : qAsConst(mPlugins)) {
+        for (KontactInterface::Plugin *plugin : std::as_const(mPlugins)) {
             if (!plugin->identifier().isEmpty() && plugin->identifier().contains(mInitialActiveModule)) {
                 selectPlugin(plugin);
                 return;
@@ -229,7 +230,7 @@ void MainWindow::activateInitialPluginModule()
 
 void MainWindow::initWidgets()
 {
-    QWidget *mTopWidget = new QWidget(this);
+    auto mTopWidget = new QWidget(this);
     auto layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
@@ -275,7 +276,7 @@ void MainWindow::paintAboutScreen(const QString &templateName, const QVariantHas
 
 void MainWindow::initAboutScreen()
 {
-    QWidget *introbox = new QWidget(mPartsStack);
+    auto introbox = new QWidget(mPartsStack);
     auto introboxHBoxLayout = new QHBoxLayout(introbox);
     introboxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     mPartsStack->addWidget(introbox);
@@ -294,7 +295,7 @@ void MainWindow::setupActions()
     actionCollection()->setDefaultShortcuts(mNewActions, KStandardShortcut::openNew());
     connect(mNewActions, &KActionMenu::triggered, this, &MainWindow::slotNewClicked);
 
-    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18nc("@action:inmenu", "Configure Kontact..."), this);
+    auto action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18nc("@action:inmenu", "Configure Kontact..."), this);
     setHelpText(action, i18nc("@info:status", "Configure Kontact"));
     action->setWhatsThis(i18nc("@info:whatsthis", "You will be presented with a dialog where you can configure Kontact."));
     actionCollection()->addAction(QStringLiteral("settings_configure_kontact"), action);
@@ -328,7 +329,7 @@ KontactInterface::Plugin *MainWindow::pluginFromName(const QString &identifier)
 void MainWindow::loadPlugins()
 {
     QList<KontactInterface::Plugin *> plugins;
-    for (const KPluginInfo &pluginInfo : qAsConst(mPluginInfos)) {
+    for (const KPluginInfo &pluginInfo : std::as_const(mPluginInfos)) {
         if (!pluginInfo.isPluginEnabled()) {
             continue;
         }
@@ -358,10 +359,10 @@ void MainWindow::loadPlugins()
         plugin->setTitle(pluginInfo.name());
         plugin->setIcon(pluginInfo.icon());
 
-        QVariant libNameProp = pluginInfo.property(QStringLiteral("X-KDE-KontactPartLibraryName"));
-        QVariant exeNameProp = pluginInfo.property(QStringLiteral("X-KDE-KontactPartExecutableName"));
-        QVariant loadOnStart = pluginInfo.property(QStringLiteral("X-KDE-KontactPartLoadOnStart"));
-        QVariant hasPartProp = pluginInfo.property(QStringLiteral("X-KDE-KontactPluginHasPart"));
+        const QVariant libNameProp = pluginInfo.property(QStringLiteral("X-KDE-KontactPartLibraryName"));
+        const QVariant exeNameProp = pluginInfo.property(QStringLiteral("X-KDE-KontactPartExecutableName"));
+        const QVariant loadOnStart = pluginInfo.property(QStringLiteral("X-KDE-KontactPartLoadOnStart"));
+        const QVariant hasPartProp = pluginInfo.property(QStringLiteral("X-KDE-KontactPluginHasPart"));
 
         if (!loadOnStart.isNull() && loadOnStart.toBool()) {
             mDelayedPreload.append(plugin);
@@ -378,7 +379,7 @@ void MainWindow::loadPlugins()
     }
     std::sort(plugins.begin(), plugins.end(), pluginWeightLessThan); // new plugins
 
-    for (KontactInterface::Plugin *plugin : qAsConst(plugins)) {
+    for (KontactInterface::Plugin *plugin : std::as_const(plugins)) {
         const QList<QAction *> actionList = plugin->newActions();
         for (QAction *action : actionList) {
             qCDebug(KONTACT_LOG) << "Plugging new action" << action->objectName();
@@ -403,7 +404,7 @@ void MainWindow::unloadDisabledPlugins()
 {
     // Only remove the now-disabled plugins.
     // Keep the other ones. loadPlugins() will skip those that are already loaded.
-    for (const KPluginInfo &pluginInfo : qAsConst(mPluginInfos)) {
+    for (const KPluginInfo &pluginInfo : std::as_const(mPluginInfos)) {
         if (!pluginInfo.isPluginEnabled()) {
             removePlugin(pluginInfo.pluginName());
         }
@@ -455,7 +456,7 @@ bool MainWindow::removePlugin(const QString &pluginName)
     }
 
     if (mCurrentPlugin == nullptr) {
-        for (KontactInterface::Plugin *plugin : qAsConst(mPlugins)) {
+        for (KontactInterface::Plugin *plugin : std::as_const(mPlugins)) {
             if (plugin->showInSideBar()) {
                 selectPlugin(plugin);
                 return true;
@@ -472,7 +473,7 @@ void MainWindow::addPlugin(KontactInterface::Plugin *plugin)
     mPlugins.append(plugin);
 
     if (plugin->showInSideBar()) {
-        QAction *action = new QAction(QIcon::fromTheme(plugin->icon()), plugin->title(), this);
+        auto action = new QAction(QIcon::fromTheme(plugin->icon()), plugin->title(), this);
         // action->setHelpText(
         //            i18nc( "@info:status", "Plugin %1", plugin->title() ) );
         action->setWhatsThis(i18nc("@info:whatsthis", "Switch to plugin %1", plugin->title()));
@@ -523,7 +524,7 @@ void MainWindow::slotNewClicked()
     if (!mCurrentPlugin->newActions().isEmpty()) {
         mCurrentPlugin->newActions().at(0)->trigger();
     } else {
-        for (KontactInterface::Plugin *plugin : qAsConst(mPlugins)) {
+        for (KontactInterface::Plugin *plugin : std::as_const(mPlugins)) {
             if (!plugin->newActions().isEmpty()) {
                 plugin->newActions().constFirst()->trigger();
                 return;
@@ -637,7 +638,7 @@ void MainWindow::selectPlugin(KontactInterface::Plugin *plugin)
             mNewActions->setText(newAction->text());
             mNewActions->setWhatsThis(newAction->whatsThis());
         } else { // we'll use the action of the first plugin which offers one
-            for (KontactInterface::Plugin *plugin : qAsConst(mPlugins)) {
+            for (KontactInterface::Plugin *plugin : std::as_const(mPlugins)) {
                 if (!plugin->newActions().isEmpty()) {
                     newAction = plugin->newActions().constFirst();
                 }
@@ -685,7 +686,7 @@ void MainWindow::loadSettings()
     }
 
     // Preload Plugins. This _must_ happen before the default part is loaded
-    for (KontactInterface::Plugin *plugin : qAsConst(mDelayedPreload)) {
+    for (KontactInterface::Plugin *plugin : std::as_const(mDelayedPreload)) {
         selectPlugin(plugin);
     }
     selectPlugin(Prefs::self()->mActivePlugin);
@@ -719,6 +720,11 @@ void MainWindow::slotPreferences()
     if (!dlg) {
         dlg = new Kontact::KontactConfigureDialog(this);
         dlg->setAllowComponentSelection(true);
+        connect(dlg, QOverload<const QByteArray &>::of(&KSettings::Dialog::configCommitted), this, [this](const QByteArray &componentName) {
+            if (componentName == QByteArrayLiteral("kontact")) {
+                MainWindow::updateConfig();
+            }
+        });
 
         // do not show settings of components running standalone
         KPluginInfo::List filteredPlugins = mPluginInfos;
@@ -820,7 +826,7 @@ void MainWindow::slotOpenUrl(const QUrl &url)
                 mPartsStack->setCurrentIndex(mPartsStack->indexOf(mCurrentPlugin->part()->widget()));
             }
         } else if (path == QLatin1String("/accountwizard")) {
-            KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(QStringLiteral("accountwizard"));
+            auto job = new KIO::CommandLauncherJob(QStringLiteral("accountwizard"));
             job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
             job->exec();
             slotQuit();
@@ -845,7 +851,7 @@ void MainWindow::readProperties(const KConfigGroup &config)
     QSet<QString> activePlugins(activePluginList.begin(), activePluginList.end());
 
     if (!activePlugins.isEmpty()) {
-        for (KontactInterface::Plugin *plugin : qAsConst(mPlugins)) {
+        for (KontactInterface::Plugin *plugin : std::as_const(mPlugins)) {
             if (!plugin->isRunningStandalone() && activePlugins.contains(plugin->identifier())) {
                 plugin->readProperties(config);
             }
@@ -859,7 +865,7 @@ void MainWindow::saveProperties(KConfigGroup &config)
 
     QStringList activePlugins;
 
-    for (const KPluginInfo &pluginInfo : qAsConst(mPluginInfos)) {
+    for (const KPluginInfo &pluginInfo : std::as_const(mPluginInfos)) {
         if (pluginInfo.isPluginEnabled()) {
             KontactInterface::Plugin *plugin = pluginFromName(pluginInfo.pluginName());
             if (plugin) {
@@ -878,7 +884,7 @@ bool MainWindow::queryClose()
         return true;
     }
 
-    for (KontactInterface::Plugin *plugin : qAsConst(mPlugins)) {
+    for (KontactInterface::Plugin *plugin : std::as_const(mPlugins)) {
         if (!plugin->isRunningStandalone()) {
             if (!plugin->queryClose()) {
                 return false;
